TaskRequest class
Constructors
- TaskRequest(String data, double fontSize, double fontHeight, double maxWidth, EdgeInsetsGeometry padding, double maxTextHeight)
Properties
- data → String
-
final
- fontHeight → double
-
final
- fontSize → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxTextHeight → double
-
final
- maxWidth → double
-
final
- padding → EdgeInsetsGeometry
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited